
From: Gerrit Huizenga <gh@us.ibm.com>

Make the configuration interface more accurately reflect the relationship
between RBCE and CRBCE.  Only the following 4 configurations are allowed:

  | CONFIG_RBCE | CONFIG_CRBCE |
--+-------------+--------------|
1 |      m      |       m      |
2 |      y      |       n      |
3 |      n      |       y      |
4 |      n      |       n      |

Signed-Off-By: Matt Helsley <matthltc@us.ibm.com>
Signed-Off-By: Gerrit Huizenga <gh@us.ibm.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 init/Kconfig |   51 +++++++++++++++++++++++++++++++++------------------
 1 files changed, 33 insertions(+), 18 deletions(-)

diff -puN init/Kconfig~ckrm-classification-engine-configuration-support-cleanup init/Kconfig
--- 25/init/Kconfig~ckrm-classification-engine-configuration-support-cleanup	Wed Jul 13 14:44:55 2005
+++ 25-akpm/init/Kconfig	Wed Jul 13 14:44:55 2005
@@ -204,29 +204,44 @@ config CKRM_RES_NUMTASKS
 	  Say N if unsure, Y to use the feature.
 
 
-config CKRM_RBCE
-	tristate "Vanilla Rule-based Classification Engine (RBCE)"
-	depends on CKRM && RCFS_FS && CKRM_CRBCE != y
-	default m
+choice
+	prompt "Classification Engine"
+	depends on CKRM && RCFS_FS
+	default CKRM_RBCE
+	optional
 	help
-	  Provides an optional module to support creation of rules for automatic
-	  classification of kernel objects. Rules are created/deleted/modified
-	  through an rcfs interface. RBCE is not required for CKRM.
+	 Select a classification engine (CE) that assists in
+	 automatic classification of kernel objects managed by CKRM when
+	 they are created. Without a CE, a user must manually
+	 classify objects into classes. Processes inherit their parent's
+	 classification.
 
-	  If unsure, say N.
+	 Only one engine can be built into the kernel though all can be
+	 built as modules (only one will load).
 
-config CKRM_CRBCE
-	tristate "Enhanced Rule-based Classification Engine (RBCE)"
-	depends on CKRM && RCFS_FS && DELAY_ACCT && CKRM_RBCE != y && NET
-	default m
+ 	 Classification engines are optional component of CKRM.
+	 If unsure, say N.
+
+config CKRM_RBCE
+	tristate "Rule-based Classification Engine (RBCE)"
 	help
-	  Provides an optional module to support creation of rules for automatic
-	  classification of kernel objects, just like RBCE above. In addition,
-	  CRBCE provides per-process delay data (requires DELAY_ACCT configured)
-	  enabled) and makes information on significant kernel events available
-	  to userspace tools through netlink.
+	  Vanilla Rule-based Classification Engine (RBCE). Rules for
+	  classifying kernel objects are created/deleted/modified through
+	  a RCFS directory using a filesystem interface.
 
-	  If unsure, say N.
+config CKRM_CRBCE
+	tristate "Enhanced Rule-based Classification Engine (CRBCE)"
+	depends on DELAY_ACCT && NET
+	help
+ 	  Enhanced Rule-based Classification Engine (CRBCE). Like the Vanilla
+ 	  RBCE, rules for classifying kernel objects are created, deleted and
+ 	  modified through a RCFS directory using a filesystem interface
+ 	  (requires CKRM_RCFS configured).
+
+ 	  In addition, CRBCE provides per-process delay data
+ 	  (requires DELAY_ACCT configured) and makes information on significant
+ 	  kernel events available to userspace tools through netlink.
+endchoice
 endmenu
 
 config SYSCTL
_
